==> echobase-ui-0.3-sources.jar: fr/ifremer/echobase/ui/actions/importData/LaunchCatchesData.java <==
/*
 * #%L
 * EchoBase :: UI
 * 
 * $Id: LaunchCatchesData.java 346 2012-03-10 00:54:19Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/echobase/tags/echobase-0.3/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/importData/LaunchCatchesData.java $
 * %%
 * Copyright (C) 2011 - 2012 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.echobase.ui.actions.importData;

import fr.ifremer.echobase.services.importdata.CatchesDataImportService;
import fr.ifremer.echobase.services.configurations.CatchesDataImportConfiguration;

/**
 * Configure a accoustic data import.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.3
 */
public class LaunchCatchesData extends AbstractLaunchImport<CatchesDataImportConfiguration, CatchesDataImportService> {

    private static final long serialVersionUID = 1L;

    public LaunchCatchesData() {
        super(CatchesDataImportConfiguration.class, CatchesDataImportService.class);
    }

}

==> echobase-ui-0.4-sources.jar: fr/ifremer/echobase/ui/actions/importData/LaunchCatchesData.java <==
/*
 * #%L
 * EchoBase :: UI
 * 
 * $Id: LaunchCatchesData.java 420 2012-03-27 23:02:51Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/echobase/tags/echobase-0.4/echobase-ui/src/main/java/fr/ifremer/echobase/ui/actions/importData/LaunchCatchesData.java $
 * %%
 * Copyright (C) 2011 - 2012 Ifremer, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package fr.ifremer.echobase.ui.actions.importData;

import fr.ifremer.echobase.services.importdata.CatchesDataImportConfiguration;
import fr.ifremer.echobase.services.importdata.CatchesDataImportService;

/**
 * Configure a accoustic data import.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 0.3
 */
public class LaunchCatchesData extends AbstractLaunchImport<CatchesDataImportConfiguration, CatchesDataImportService> {

    private static final long serialVersionUID = 1L;

    public LaunchCatchesData() {
        super(CatchesDataImportConfiguration.class, CatchesDataImportService.class);
    }

}
